@@ -14,6 +14,7 @@ mod cmd_simplify;
 mod cmd_voronoi;
 mod cmd_voronoi_mesh;
 mod cmd_voxel;
+mod lsystems_3d;
 mod voronoi_utils;
 
 use crate::toxicblend_pb::Command as PB_Command;
@@ -91,6 +92,9 @@ pub enum TBError {
     #[error("Something is wrong with the internal logic: {0}")]
     InternalError(String),
 
+    #[error("Could not parse string: {0}")]
+    ParseError(String),
+
     #[error("Something is wrong with the input data")]
     CouldNotCalculateInvertMatrix,
 
@@ -114,6 +118,9 @@ pub enum TBError {
 
     #[error(transparent)]
     BoostVoronoiError(#[from] boostvoronoi::BvError),
+
+    #[error("Error in LSystems {0}")]
+    LSystems3D(String),
 }
 
 #[derive(Debug, Default)]
